All Modules, Classes, and Methods — GDA Toolbox v1.0 Manual

# All Modules, Classes, and Methods

An alphabetical list of everything.

`homology` | This module defines the the basic objects for persistence diagrams:
`homology.PersDiag`(birth_index, death_index, …) | Persistence Diagrams and related merge-tree information.
`homology.PersDiag.bin`(width[, underflow, …]) | Count bins on the transformed persistence diagram.
`homology.PersDiag.bin_bot`(width[, …]) |
`homology.PersDiag.bin_diag`(width[, …]) |
`homology.PersDiag.bin_len`(width[, …]) |
`homology.PersDiag.bin_top`(width[, …]) |
`homology.PersDiag.clip`(beta) | clip the barcode below beta.
`homology.PersDiag.grab`(n) | clip the barcode, using only the top n entries.
`homology.PersDiag.plot`(canvas[, transform, …]) | Plot the persistence diagram using `matplotlib` or `bokeh`.
`homology.PersDiag.syzygy`(powers) | compute the syzygy coordinate of my barcode.
`homology.PersDiag.transform`([transform, points]) | Produce an array of points, obtained by transforming the persistence diagram.
`homology.dim0` | This Cython module contains the core algorithms for 0-dimension topological algorithms.
`homology.dim0.all_roots` | Reference each vertex directly to its representative root, from MergeTree.
`homology.dim0.mkforestDBL` | Make inclusion tree and parentage linked lists by walking across This method is for `np.float64` arrays (for indexing speed).
`homology.dim0.unionfind` | Apply the UnionFind algorithm to compute zero-dimensional persistence diagram.
`homology.dim1` | This Cython module contains the core algorithms for 1-dimensional topological algorithms.
`multidim` | The `multidim` class provides user-facing tools for topological data analysis of multi-dimensional data.
`multidim.PointCloud`(data_array[, …]) | PointCloud is a class for embedded, weighted simplicial complexes.
`multidim.PointCloud.cache_usage`() | Compute the size of the distance cache.
`multidim.PointCloud.cells`(dim) | iterate over all `Simplex` objects of dimension dim.
`multidim.PointCloud.check`() | Run consistency checks on all simplices in all dimensions.
`multidim.PointCloud.cover_ball`([point_index]) | Find a ball that covers the entire PointCloud.
`multidim.PointCloud.dists`(indices0, indices1) | Compute distances points indices0 and indices1.
`multidim.PointCloud.from_distances`(dists[, …]) | Construct a SimplicialComplex from a symmetric matrix of distances.
`multidim.PointCloud.from_multisample_multilabel`(…) | Produce a single labeled and weighted pointcloud from a list of samples and labels of those samples.
`multidim.PointCloud.gaussian_fit`([center]) | Fit a normalized Gaussian to this cloud (using SVD).
`multidim.PointCloud.make_pers0`([cutoff]) | Run the UnionFind algorithm to mark connected components of the SimplicialComplex.
`multidim.PointCloud.make_pers1_rca1`([cutoff]) | Run RCA1 and make a 1-dimensional `homology.PersDiag` for the edge-pairings for cycle generators.
`multidim.PointCloud.nearest_neighbors`(k) | Compute k nearest-neighbors of the PointCloud, using a clever CoverTree algorithm.
`multidim.PointCloud.plot`(canvas[, cutoff, …]) | Plot a PointCloud, decorated by various proeprties.
`multidim.PointCloud.reset`() | delete persistence diagrams, and forget all representative and positivity information.
`multidim.PointCloud.sever`() | Subdivide PointCloud into several smaller PointClouds, using the known 0-dimensional persistence diagram.
`multidim.PointCloud.unique_with_multiplicity`() | Look for duplicate points, and mark their multiplicity.
`multidim.PointCloud.witnessed_barycenters`(k) | Build the PointCloud of k-witnessed barycenters, weighted by distance-to-measure.
`multidim.SimplicialComplex`([stratum]) | A class for abstract weighted simplicial complexes.
`multidim.SimplicialComplex.cells`(dim) | iterate over all `Simplex` objects of dimension dim.
`multidim.SimplicialComplex.check`() | Run consistency checks on all simplices in all dimensions.
`multidim.SimplicialComplex.from_distances`(dists) | Construct a SimplicialComplex from a symmetric matrix of distances.
`multidim.SimplicialComplex.make_pers0`([cutoff]) | Run the UnionFind algorithm to mark connected components of the SimplicialComplex.
`multidim.SimplicialComplex.make_pers1_rca1`([…]) | Run RCA1 and make a 1-dimensional `homology.PersDiag` for the edge-pairings for cycle generators.
`multidim.SimplicialComplex.reset`() | delete persistence diagrams, and forget all representative and positivity information.
`multidim.covertree` | This module contains the essential classes for the “Cover-tree with friends” algorithm, namely:
`multidim.covertree.CoverLevel`(covertree, …) | A thin class to represent one level of the filtration in a `CoverTree`.
`multidim.covertree.CoverTree`(pointcloud[, …]) | An efficient and convenient implementation of the “Cover Tree with Friends” algorithm.
`multidim.fast_algorithms` | This Cython module contains core algorithms for multidimensional data.
`multidim.models` | This module contains classifiers based on the SciKitLearn framework.
`multidim.models.CDER`([stop_level]) | The CDER (Cover-Tree Differencing for Entropy Reduction) algorithm for supervised machine-learning of labelled cloud collections.
`multidim.models.GaussianMixtureClassifier`([…]) | A scikit-learn classification estimator, for any sort of Gaussian mixture model.
`timeseries` | This module defines tools for geometric analysis of one-dimensional (time-series) data sets.
`timeseries.jagged`(persdiag, index) | Produce a piecewise-linear function that matches the given persistence diagram.
`timeseries.Signal`(values[, times]) |
`timeseries.Signal.feature`([index]) | return the region of a feature, with vertical displacement threshold tau.
`timeseries.Signal.feature_match`(other[, …]) |
`timeseries.Signal.from_pointcloud`(points, …) |
`timeseries.Signal.gap`() | Return the largest homology.
`timeseries.Signal.height_measure`([sigma, …]) | Use a simulation to estimate the height-measure of an interval.
`timeseries.Signal.interval_height`(interval) | the indicator-persistence function for intervals, called h_U(A) in the notes.
`timeseries.Signal.iter_features`([min_pers, …]) | walk the feature tree.
`timeseries.Signal.iter_intervals`() | return the itertools combinations iterator over all sub-intervals.
`timeseries.Signal.iter_windows_by_index`(window) | Produce equal-length Signals using a sliding-window on self.
`timeseries.Signal.jagged`([beta]) | call `timeseries.jagged()` on this `Signal`’s own persistence diagram.
`timeseries.Signal.normalize`() | change this Signal object to have mean = 0 and max-min = 1
`timeseries.Signal.plot`(canvas[, title]) | Plot the Signal.
`timeseries.Signal.profile`(arch[, normalize, …]) | produce profile by dragging an archetype across self, looking for matches.
`timeseries.Signal.sample_near`([sigma]) | return a Signal object that is L2-near self in the normal distribution.
`timeseries.Signal.self_similarity`(window[, …]) | Compare sliding windows of this Signal using a distance function.
`timeseries.SpaceCurve`(tn[, px, py, pz, …]) | SpaceCurve is a Python class for studying curves in \(\mathbb{R}^2\) or \(\mathbb{R}^3\).
`timeseries.SpaceCurve.accel`(rate) | Change time parametrization, to represent a constant tangential acceleration (or deceleration).
`timeseries.SpaceCurve.arclength_param`() | Change time parametrization to the universal speed=1 arclength parametrization.
`timeseries.SpaceCurve.auto_bin`([num_bins, …]) | Count bins on the transformed persistence diagrams of -Speed/7 (so it is expected to be between 0 and 100) -Climb/3 (so it is expected to be between 0 and 100) -Curvature*10000 (so it is expected to be between 0 and 100) -Torsion*10000 (so it is expected to be between 0 and 100) -Bank*100/(pi/4) (==grade, between 0 and 100)
`timeseries.SpaceCurve.clean_copy`([cleanup_func]) | Make copy in which a cleanup function performed on the data.
`timeseries.SpaceCurve.compute`() | Compute some nice invariants and store them to self.info.
`timeseries.SpaceCurve.copy`() | make an identical copy of self.
`timeseries.SpaceCurve.duration`() | return string of duraction of SpaceCurve, converting integer nanoseconds to string seconds.
`timeseries.SpaceCurve.featurize`([…]) | A convenience function to compute everything we think might be important.
`timeseries.SpaceCurve.lift_and_mass`() | Produce the terms of the force-balance equations, to help derive coefficient-of-lift and mass from pure trajectory information.
`timeseries.SpaceCurve.lift_profile`([…]) | histogram of the lift_and_mass by lift.
`timeseries.SpaceCurve.load`(filename) | Simple CSV reader.
`timeseries.SpaceCurve.mass_profile`([…]) | histogram of the lift_and_mass by mass.
`timeseries.SpaceCurve.plot`(canvas[, title, …]) | Plot the SpaceCurve in 3D.
`timeseries.SpaceCurve.reparam`(rate) | Change time parametrization, to represent a constant change of speed.
`timeseries.SpaceCurve.reverse`() | Reverse the time parametrization of the SpaceCurve.
`timeseries.SpaceCurve.signature_curve`() | Olver/Boutin signature curve.
`timeseries.SpaceCurve.slide`([window, …]) | Produce equal-time SpaceCurves using a sliding-window on self.
`timeseries.SpaceCurve.snip`([time_step, …]) | Cut this SpaceCurve into equal-time snippets.
`timeseries.test_mollifier` | Test the mollifier code
`timeseries.test_mollifier.TestMollifier` |
`timeseries.test_mollifier.TestMollifier.setup`() |
`timeseries.test_mollifier.TestMollifier.setup_method`(…) |
`timeseries.test_mollifier.TestMollifier.teardown`() |
`timeseries.test_mollifier.TestMollifier.teardown_method`(…) |
`timeseries.test_mollifier.TestMollifier.test_refinement_counts`() |
`timeseries.test_mollifier.TestMollifier.test_resonable_reconstruction`() |

#### Previous topic

homology.dim1

#### Next topic

homology